Name:          libva
Version:       1.5.1
Release:       1mamba
Summary:       VAAPI (Video Acceleration API) Library for Linux
Group:         System/Libraries
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           http://www.freedesktop.org/wiki/Software/vaapi
Source:        http://cgit.freedesktop.org/libva/snapshot/libva-%{version}.tar.gz
License:       GPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libdrm-devel
BuildRequires: libGL-devel
BuildRequires: libpthread-stubs-devel
BuildRequires: libX11-devel
BuildRequires: libXau-devel
BuildRequires: libxcb-devel
BuildRequires: libXdmcp-devel
BuildRequires: libXext-devel
BuildRequires: libXfixes-devel
## AUTOBUILDREQ-END
BuildRequires: gettext-devel
%ifnarch arm
BuildRequires: intel-gpu-tools
%endif
BuildRequires: libwayland-devel
BuildRoot:     %{_tmppath}/%{name}-%{version}-root

%description
The main motivation for VAAPI (Video Acceleration API) is to enable hardware accelerated video decode/encode at various entry-points (VLD, IDCT, Motion Compensation etc.) for the prevailing coding standards today (MPEG-2, MPEG-4 ASP/H.263, MPEG-4 AVC/H.264, and VC-1/VMW3). Extending XvMC was considered, but due to its original design for MPEG-2 MotionComp only, it made more sense to design an interface from scratch that can fully expose the video decode capabilities in today's GPUs.
The current video decode/encode interface is window system independent, so that potentially it can be used with graphics sub-systems other than X. In a nutshell it is basically a scheme to pass various types of data buffers from the application to the GPU for decoding or encoding. Feedback on the API is greatly welcomed, as this is intended to be a community collaborative effort.

%package devel
Group:         Development/Libraries
Summary:       Libraries and headers for %{name}
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description devel
The libva library implements the Video Acceleration (VA) API for Linux. The library loads a hardware dependendent driver.
This package contains libraries and header files needed for development.

%package drivers
Group:         System/Kernel and Hardware
Summary:       Video Acceleration (VA) API for Linux -- hardware drivers
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description drivers
The libva library implements the Video Acceleration (VA) API for Linux. The library loads a hardware dependendent driver.
This package contains the hardware drivers.

%package static
Group:         Development/Libraries
Summary:       Static libraries for %{name}
Requires:      %{name}-devel = %{?epoch:%epoch:}%{version}-%{release}

%description static
The libva library implements the Video Acceleration (VA) API for Linux. The library loads a hardware dependendent driver.
This package contains static libraries needed for development.

%package tools
Group:         System/Libraries
Summary:       Video Acceleration (VA) API for Linux -- tools
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description tools
The libva library implements the Video Acceleration (VA) API for Linux. The library loads a hardware dependendent driver.
This package contains a set of tools around vaapi library.

%prep
%setup -q

%build
./autogen.sh
%configure \
%ifarch %{ix86} x86_64
  --enable-i965-driver
%endif

%make

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%makeinstall

rm -rf %{buildroot}%{_libdir}/dri/*.la
rm -rf %{buildroot}%{_bindir}/test_*

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_libdir}/libva.so.*
%{_libdir}/libva-drm.so.*
%{_libdir}/libva-egl.so.*
%{_libdir}/libva-glx.so.*
%{_libdir}/libva-tpi.so.*
%{_libdir}/libva-wayland.so.*
%{_libdir}/libva-x11.so.*
%doc COPYING

%files devel
%defattr(-,root,root)
%{_bindir}/putsurface_wayland
%dir %{_includedir}/va
%{_includedir}/va/*.h
%{_libdir}/libva.so
%{_libdir}/libva-glx.so
%{_libdir}/libva-tpi.so
%{_libdir}/libva-drm.la
%{_libdir}/libva-drm.so
%{_libdir}/libva-egl.la
%{_libdir}/libva-egl.so
%{_libdir}/libva-wayland.la
%{_libdir}/libva-wayland.so
%{_libdir}/libva-x11.so
%{_libdir}/pkgconfig/libva-drm.pc
%{_libdir}/pkgconfig/libva-egl.pc
%{_libdir}/pkgconfig/libva-glx.pc
%{_libdir}/pkgconfig/libva-tpi.pc
%{_libdir}/pkgconfig/libva-wayland.pc
%{_libdir}/pkgconfig/libva-x11.pc
%{_libdir}/pkgconfig/libva.pc

%files drivers
%defattr(-,root,root)
%{_libdir}/dri/dummy_drv_video.so
#%ifarch %{ix86} x86_64
#%{_libdir}/dri/i965_drv_video.so
#%endif

%files tools
%defattr(-,root,root)
%{_bindir}/avcenc
%{_bindir}/jpegenc
%{_bindir}/loadjpeg
%{_bindir}/h264encode
%{_bindir}/mpeg2vaenc
%{_bindir}/mpeg2vldemo
%{_bindir}/putsurface
%{_bindir}/vainfo

%files static
%defattr(-,root,root)
%{_libdir}/libva.la
%{_libdir}/libva-glx.la
%{_libdir}/libva-tpi.la
%{_libdir}/libva-x11.la

%changelog
* Thu Apr 09 2015 Automatic Build System <autodist@mambasoft.it> 1.5.1-1mamba
- automatic version update by autodist

* Mon Dec 29 2014 Automatic Build System <autodist@mambasoft.it> 1.5.0-1mamba
- automatic version update by autodist

* Fri Oct 24 2014 Automatic Build System <autodist@mambasoft.it> 1.4.1-1mamba
- automatic version update by autodist

* Tue Sep 30 2014 Automatic Build System <autodist@mambasoft.it> 1.4.0-1mamba
- automatic version update by autodist

* Sun May 11 2014 Automatic Build System <autodist@mambasoft.it> 1.3.1-1mamba
- automatic version update by autodist

* Sun Mar 30 2014 Automatic Build System <autodist@mambasoft.it> 1.3.0-1mamba
- automatic version update by autodist

* Fri Jun 28 2013 Automatic Build System <autodist@mambasoft.it> 1.2.1-1mamba
- automatic version update by autodist

* Wed Apr 10 2013 Automatic Build System <autodist@mambasoft.it> 1.1.1-1mamba
- automatic version update by autodist

* Mon Dec 10 2012 Automatic Build System <autodist@mambasoft.it> 1.1.0-1mamba
- automatic version update by autodist

* Mon Feb 07 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.8-1mamba
- update to 1.0.8

* Mon Dec 27 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.6-2mamba
- automatic port from devel-gil

* Mon Dec 20 2010 gil <puntogil@libero.it> 1.0.6-1mamba
- update to 1.0.6

* Mon Jul 05 2010 gil <puntogil@libero.it> 1.0.3-1mamba
- package created by autospec
